# frozen_string_literal: true

RSpec.describe "catalog/show.json" do
  let(:document) do
    SolrDocument.new(id: '123', title_tsim: 'Book1', author_tsim: 'Julie', format: 'Book')
  end
  let(:config) do
    Blacklight::Configuration.new do |config|
      config.show.title_field = 'title_tsim'
    end
  end

  let(:hash) do
    render template: "catalog/show", formats: [:json]
    JSON.parse(rendered).with_indifferent_access
  end

  before do
    allow(view).to receive_messages(blacklight_config: config, action_name: 'show')
    assign :document, document
  end

  it "includes document attributes" do
    expect(hash).to include(data:
      {
        id: '123',
        type: 'Book',
        attributes: {
          'title' => 'Book1'
        }
      })
  end
end
